@@ -209,12 +209,17 @@ nsPipeChannel::Init(nsIURI* aURI,
     nsCOMPtr<nsIMIMEService> MIMEService (do_GetService("@mozilla.org/mime;1", &rv));
     if (NS_FAILED(rv)) return rv;
 
+#ifdef MOZ_THUNDERBIRD
+    char *contentType = nsnull;
+    rv = MIMEService->GetTypeFromURI(url, (char **)&contentType);
+#else
+    // Mozilla >= 1.8a1
     nsXPIDLCString contentType;
     rv = MIMEService->GetTypeFromURI(url, contentType);
+#endif
     if (NS_SUCCEEDED(rv) && contentType) {
       mContentType.Assign(contentType);
     }
-
   }
 
   // Create an instance of pipe transport
