@@ -39,6 +39,7 @@
 #include "nsCRT.h"
 #include "nsReadableUtils.h"
 #include "netCore.h"
+#include "nsEventQueueUtils.h"
 
 #include "nsIServiceManager.h"
 #include "nsIProxyObjectManager.h"
@@ -159,8 +160,8 @@ NS_IMPL_THREADSAFE_ISUPPORTS8(nsPipeTransport,
                               nsIRequest,
                               nsIOutputStream,
                               nsIStreamListener,
-                              nsIInputStreamNotify,
-                              nsIOutputStreamNotify);
+                              nsIInputStreamCallback,
+                              nsIOutputStreamCallback);
 #else // !MOZILLA_VERSION
 // Mods for Mozilla version prior to 1.3b
 NS_IMPL_THREADSAFE_ISUPPORTS8(nsPipeTransport, 
@@ -921,9 +922,16 @@ nsPipeTransport::AsyncRead(nsIStreamListener *listener,
     mInputStream = asyncInputStream;
     mOutputStream = asyncOutputStream;
 
+    nsCOMPtr<nsIEventQueue> eventQ;
+
+    if (!mNoProxy) {
+      rv = NS_GetCurrentEventQ(getter_AddRefs(eventQ));
+      if (NS_FAILED(rv)) return rv;
+    }
+
     // Set input stream observer (using event queue, if need be)
-    rv = asyncInputStream->AsyncWait((nsIInputStreamNotify*) this,
-                                      0, mNoProxy ? NULL : NS_CURRENT_EVENTQ);
+    rv = asyncInputStream->AsyncWait((nsIInputStreamCallback*) this,
+                                      0, 0, eventQ);
     if (NS_FAILED(rv)) return rv;
 
 #else // !MOZILLA_VERSION
@@ -1470,7 +1478,7 @@ nsPipeTransport::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext,
 #ifdef MOZILLA_VERSION
 
 ///////////////////////////////////////////////////////////////////////////////
-// nsIInputStreamNotify methods:
+// nsIInputStreamCallback methods:
 // (Should be invoked in the thread creating nsIPipeTransport object,
 //  unless mNoProxy is true.)
 ///////////////////////////////////////////////////////////////////////////////
@@ -1502,9 +1510,15 @@ nsPipeTransport::OnInputStreamReady(nsIAsyncInputStream* inStr)
                                      mInputStream, 0, available);
     if (NS_FAILED(rv)) return rv;
 
+    nsCOMPtr<nsIEventQueue> eventQ;
+
+    if (!mNoProxy) {
+      rv = NS_GetCurrentEventQ(getter_AddRefs(eventQ));
+      if (NS_FAILED(rv)) return rv;
+    }
+
     // Re-set input stream observer (using event queue, if need be)
-    rv = inStr->AsyncWait((nsIInputStreamNotify*) this,
-                          0, mNoProxy ? NULL : NS_CURRENT_EVENTQ);
+    rv = inStr->AsyncWait((nsIInputStreamCallback*) this, 0, 0, eventQ);
     if (NS_FAILED(rv)) return rv;
 
     return rv;
@@ -1514,7 +1528,7 @@ nsPipeTransport::OnInputStreamReady(nsIAsyncInputStream* inStr)
 }
 
 ///////////////////////////////////////////////////////////////////////////////
-// nsIOutputStreamNotify methods:
+// nsIOutputStreamCallback methods:
 // (Should be invoked in the thread creating nsIPipeTransport object)
 ///////////////////////////////////////////////////////////////////////////////
 
